@@ -35,7 +35,6 @@
 
 #include "nautilus-file-attributes.h"
 #include "nautilus-file.h"
-#include "nautilus-autorun.h"
 #include "nautilus-file-operations.h"
 #include "nautilus-metadata.h"
 #include "nautilus-program-choosing.h"
@@ -223,7 +222,7 @@ static void
 application_launch_parameters_free (ApplicationLaunchParameters *parameters)
 {
 	g_object_unref (parameters->application);
-	eel_g_list_free_deep (parameters->uris);
+	g_list_free_full (parameters->uris, g_free);
 
 	g_free (parameters);
 }			      
@@ -481,7 +480,7 @@ nautilus_mime_has_any_applications_for_file (NautilusFile *file)
 		
 	if (apps) {
 		result = TRUE;
-		eel_g_object_list_free (apps);
+		g_list_free_full (apps, g_object_unref);
 	} else {
 		result = FALSE;
 	}
@@ -676,7 +675,7 @@ trash_or_delete_files (GtkWindow *parent_window,
 	nautilus_file_operations_trash_or_delete (locations,
 						  parent_window,
 						  NULL, NULL);
-	eel_g_object_list_free (locations);
+	g_list_free_full (locations, g_object_unref);
 }
 
 static void
@@ -729,7 +728,7 @@ report_broken_symbolic_link (GtkWindow *parent_window, NautilusFile *file)
 	 */
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	if (response == GTK_RESPONSE_YES) {
 		file_as_list.data = file;
@@ -794,7 +793,7 @@ get_executable_text_file_action (GtkWindow *parent_window, NautilusFile *file)
 	g_free (detail);
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 	
 	switch (response) {
 	case RESPONSE_RUN:
@@ -1124,7 +1123,7 @@ confirm_multiple_windows (GtkWindow *parent_window,
 	g_free (detail);
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	return response == GTK_RESPONSE_YES;
 }
