@@ -26,6 +26,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+#include <eel/eel-glib-extensions.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-thumbnails.h>
@@ -51,7 +52,7 @@ static NautilusIconInfo *
 fm_icon_container_get_icon_images (NautilusIconContainer *container,
 				   NautilusIconData      *data,
 				   int                    size,
-				   GList                **emblem_pixbufs,
+				   GList                **emblem_icons,
 				   char                 **embedded_text,
 				   gboolean               for_drag_accept,
 				   gboolean               need_large_embeddded_text,
@@ -63,7 +64,6 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 	NautilusFile *file;
 	gboolean use_embedding;
 	NautilusFileIconFlags flags;
-	guint emblem_size;
 
 	file = (NautilusFile *) data;
 
@@ -77,20 +77,12 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 		use_embedding = *embedded_text != NULL;
 	}
 	
-	if (emblem_pixbufs != NULL) {
-		emblem_size = nautilus_icon_get_emblem_size_for_icon_size (size);
-		/* don't return images larger than the actual icon size */
-		emblem_size = MIN (emblem_size, size);
-
-		if (emblem_size > 0) {
-			emblems_to_ignore = fm_directory_view_get_emblem_names_to_exclude 
-				(FM_DIRECTORY_VIEW (icon_view));
-			*emblem_pixbufs = nautilus_file_get_emblem_pixbufs (file,
-									    emblem_size,
-									    FALSE,
-									    emblems_to_ignore);
-			g_strfreev (emblems_to_ignore);
-		}
+	if (emblem_icons != NULL) {
+		emblems_to_ignore = fm_directory_view_get_emblem_names_to_exclude 
+			(FM_DIRECTORY_VIEW (icon_view));
+		*emblem_icons = nautilus_file_get_emblem_icons (file,
+								emblems_to_ignore);
+		g_strfreev (emblems_to_ignore);
 	}
 
 	*has_window_open = nautilus_file_has_open_window (file);
@@ -197,24 +189,25 @@ fm_icon_container_get_icon_text_attributes_from_preferences (void)
 	static GQuark *attributes = NULL;
 
 	if (attributes == NULL) {
-		eel_preferences_add_auto_string_array_as_quarks (NAUTILUS_PREFERENCES_ICON_VIEW_CAPTIONS,
-								 &attributes);
+		eel_g_settings_add_auto_strv_as_quarks (nautilus_icon_view_preferences,
+							NAUTILUS_PREFERENCES_ICON_VIEW_CAPTIONS,
+							&attributes);
 	}
-	
+
 	/* We don't need to sanity check the attributes list even though it came
 	 * from preferences.
 	 *
 	 * There are 2 ways that the values in the list could be bad.
 	 *
-	 * 1) The user picks "bad" values.  "bad" values are those that result in 
+	 * 1) The user picks "bad" values.  "bad" values are those that result in
 	 *    there being duplicate attributes in the list.
 	 *
 	 * 2) Value stored in GConf are tampered with.  Its possible physically do
 	 *    this by pulling the rug underneath GConf and manually editing its
-	 *    config files.  Its also possible to use a third party GConf key 
+	 *    config files.  Its also possible to use a third party GConf key
 	 *    editor and store garbage for the keys in question.
 	 *
-	 * Thankfully, the Nautilus preferences machinery deals with both of 
+	 * Thankfully, the Nautilus preferences machinery deals with both of
 	 * these cases.
 	 *
 	 * In the first case, the preferences dialog widgetry prevents
