@@ -34,7 +34,6 @@
 #include "nautilus-actions.h"
 #include "nautilus-application.h"
 #include "nautilus-bookmarks-window.h"
-#include "nautilus-main.h"
 #include "nautilus-location-bar.h"
 #include "nautilus-query-editor.h"
 #include "nautilus-search-bar.h"
@@ -55,7 +54,6 @@
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
-#include <libnautilus-private/nautilus-horizontal-splitter.h>
 #include <libnautilus-private/nautilus-icon-info.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
@@ -88,9 +86,6 @@ enum {
 	ARG_APP
 };
 
-static int side_pane_width_auto_value = 0;
-
-
 /* Forward and back buttons on the mouse */
 static gboolean mouse_extra_buttons = TRUE;
 static int mouse_forward_button = 9;
@@ -140,7 +135,7 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	window->details->header_size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 	gtk_size_group_set_ignore_hidden (window->details->header_size_group, FALSE);
 
-	window->details->content_paned = nautilus_horizontal_splitter_new ();
+	window->details->content_paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_table_attach (GTK_TABLE (NAUTILUS_WINDOW (window)->details->table),
 			  window->details->content_paned,
 			  /* X direction */                   /* Y direction */
@@ -150,10 +145,11 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	gtk_widget_show (window->details->content_paned);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	nautilus_horizontal_splitter_pack2 (NAUTILUS_HORIZONTAL_SPLITTER (window->details->content_paned), vbox);
+	gtk_paned_pack2 (GTK_PANED (window->details->content_paned), vbox,
+			 TRUE, FALSE);
 	gtk_widget_show (vbox);
 
-	hpaned = gtk_hpaned_new ();
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (vbox), hpaned, TRUE, TRUE, 0);
 	gtk_widget_show (hpaned);
 	window->details->split_view_hpane = hpaned;
@@ -187,19 +183,21 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 
 	nautilus_navigation_window_initialize_toolbars (window);
 
-	/* Set initial sensitivity of some buttons & menu items 
+	/* Set initial sensitivity of some buttons & menu items
 	 * now that they're all created.
 	 */
 	nautilus_navigation_window_allow_back (window, FALSE);
 	nautilus_navigation_window_allow_forward (window, FALSE);
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY,
-						  always_use_location_entry_changed,
-						  window, G_OBJECT (window));
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY,
+				  G_CALLBACK(always_use_location_entry_changed),
+				  window);
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER,
-						  always_use_browser_changed,
-						  window, G_OBJECT (window));
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER,
+				  G_CALLBACK(always_use_browser_changed),
+				  window);
 }
 
 static void
@@ -211,7 +209,7 @@ always_use_location_entry_changed (gpointer callback_data)
 
 	window = NAUTILUS_NAVIGATION_WINDOW (callback_data);
 
-	use_entry = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY);
+	use_entry = g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY);
 
 	for (walk = NAUTILUS_WINDOW(window)->details->panes; walk; walk = walk->next) {
 		nautilus_navigation_window_pane_always_use_location_entry (walk->data, use_entry);
@@ -240,9 +238,9 @@ always_use_browser_changed (gpointer callback_data)
 static void
 mouse_back_button_changed (gpointer callback_data)
 {
-	int new_back_button;	
+	int new_back_button;
 
-	new_back_button = eel_preferences_get_integer (NAUTILUS_PREFERENCES_MOUSE_BACK_BUTTON);
+	new_back_button = g_settings_get_int (nautilus_preferences, NAUTILUS_PREFERENCES_MOUSE_BACK_BUTTON);
 
 	/* Bounds checking */
 	if (new_back_button < 6 || new_back_button > UPPER_MOUSE_LIMIT)
@@ -254,9 +252,9 @@ mouse_back_button_changed (gpointer callback_data)
 static void
 mouse_forward_button_changed (gpointer callback_data)
 {
-	int new_forward_button;	
+	int new_forward_button;
 
-	new_forward_button = eel_preferences_get_integer (NAUTILUS_PREFERENCES_MOUSE_FORWARD_BUTTON);
+	new_forward_button = g_settings_get_int (nautilus_preferences, NAUTILUS_PREFERENCES_MOUSE_FORWARD_BUTTON);
 
 	/* Bounds checking */
 	if (new_forward_button < 6 || new_forward_button > UPPER_MOUSE_LIMIT)
@@ -268,7 +266,7 @@ mouse_forward_button_changed (gpointer callback_data)
 static void
 use_extra_mouse_buttons_changed (gpointer callback_data)
 {
-	mouse_extra_buttons = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS);
+	mouse_extra_buttons = g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS);
 }
 
 void
@@ -364,37 +362,28 @@ side_pane_size_allocate_callback (GtkWidget *widget,
 				  gpointer user_data)
 {
 	NautilusNavigationWindow *window;
-	
+
 	window = NAUTILUS_NAVIGATION_WINDOW (user_data);
-	
+
 	if (allocation->width != window->details->side_pane_width) {
 		window->details->side_pane_width = allocation->width;
-		if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH)) {
-			eel_preferences_set_integer
-				(NAUTILUS_PREFERENCES_SIDEBAR_WIDTH, 
-				 allocation->width <= 1 ? 0 : allocation->width);
-		}
+		g_settings_set_int (nautilus_window_state,
+				    NAUTILUS_WINDOW_STATE_SIDEBAR_WIDTH,
+				    allocation->width <= 1 ? 0 : allocation->width);
 	}
 }
 
 static void
 setup_side_pane_width (NautilusNavigationWindow *window)
 {
-	static gboolean setup_auto_value= TRUE;
-
 	g_return_if_fail (window->sidebar != NULL);
-	
-	if (setup_auto_value) {
-		setup_auto_value = FALSE;
-		eel_preferences_add_auto_integer 
-			(NAUTILUS_PREFERENCES_SIDEBAR_WIDTH,
-			 &side_pane_width_auto_value);
-	}
 
-	window->details->side_pane_width = side_pane_width_auto_value;
+	window->details->side_pane_width =
+		g_settings_get_int (nautilus_window_state,
+				    NAUTILUS_WINDOW_STATE_SIDEBAR_WIDTH);
 
-	gtk_paned_set_position (GTK_PANED (window->details->content_paned), 
-				side_pane_width_auto_value);
+	gtk_paned_set_position (GTK_PANED (window->details->content_paned),
+				window->details->side_pane_width);
 }
 
 static void
@@ -427,13 +416,11 @@ side_pane_switch_page_callback (NautilusSidePane *side_pane,
 	if (sidebar == NULL) {
 		return;
 	}
-		
+
 	set_current_side_panel (window, sidebar);
 
 	id = nautilus_sidebar_get_sidebar_id (sidebar);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW)) {
-		eel_preferences_set (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW, id);
-	}
+	g_settings_set_string (nautilus_window_state, NAUTILUS_WINDOW_STATE_SIDE_PANE_VIEW, id);
 }
 
 static void
@@ -477,7 +464,7 @@ nautilus_navigation_window_tear_down_sidebar (NautilusNavigationWindow *window)
 {
 	GList *node, *next;
 	NautilusSidebar *sidebar_panel;
-	
+
 	g_signal_handlers_disconnect_by_func (window->sidebar,
 					      side_pane_switch_page_callback,
 					      window);
@@ -510,8 +497,8 @@ nautilus_navigation_window_state_event (GtkWidget *widget,
 					GdkEventWindowState *event)
 {
 	if (event->changed_mask & GDK_WINDOW_STATE_MAXIMIZED) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_MAXIMIZED,
-					     event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED);
+		g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_MAXIMIZED,
+					event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED);
 	}
 
 	if (GTK_WIDGET_CLASS (parent_class)->window_state_event != NULL) {
@@ -575,7 +562,7 @@ nautilus_navigation_window_button_press_event (GtkWidget *widget,
 }
 
 static void
-nautilus_navigation_window_destroy (GtkObject *object)
+nautilus_navigation_window_destroy (GtkWidget *object)
 {
 	NautilusNavigationWindow *window;
 	
@@ -591,18 +578,25 @@ nautilus_navigation_window_destroy (GtkObject *object)
 	window->details->content_paned = NULL;
 	window->details->split_view_hpane = NULL;
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	GTK_WIDGET_CLASS (parent_class)->destroy (object);
 }
 
 static void
 nautilus_navigation_window_finalize (GObject *object)
 {
 	NautilusNavigationWindow *window;
-	
+
 	window = NAUTILUS_NAVIGATION_WINDOW (object);
 
 	nautilus_navigation_window_remove_go_menu_callback (window);
 
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      always_use_browser_changed,
+					      window);
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      always_use_location_entry_changed,
+					      window);
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -650,7 +644,7 @@ nautilus_navigation_window_add_sidebar_panel (NautilusNavigationWindow *window,
 
 	/* Show if default */
 	sidebar_id = nautilus_sidebar_get_sidebar_id (sidebar_panel);
-	default_id = eel_preferences_get (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW);
+	default_id = g_settings_get_string (nautilus_window_state, NAUTILUS_WINDOW_STATE_SIDE_PANE_VIEW);
 	if (sidebar_id && default_id && !strcmp (sidebar_id, default_id)) {
 		nautilus_side_pane_show_panel (window->sidebar,
 					       GTK_WIDGET (sidebar_panel));
@@ -730,7 +724,7 @@ real_sync_title (NautilusWindow *window,
 		/* if spatial mode is default, we keep "File Browser" in the window title
 		 * to recognize browser windows. Otherwise, we default to the directory name.
 		 */
-		if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
+		if (!g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
 			full_title = g_strdup_printf (_("%s - File Browser"), slot->title);
 			window_title = eel_str_middle_truncate (full_title, MAX_TITLE_LENGTH);
 			g_free (full_title);
@@ -907,28 +901,22 @@ nautilus_navigation_window_toolbar_showing (NautilusNavigationWindow *window)
 	return TRUE;
 }
 
-void 
+void
 nautilus_navigation_window_hide_status_bar (NautilusNavigationWindow *window)
 {
 	gtk_widget_hide (NAUTILUS_WINDOW (window)->details->statusbar);
 
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR) &&
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR, FALSE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_STATUS_BAR, FALSE);
 }
 
-void 
+void
 nautilus_navigation_window_show_status_bar (NautilusNavigationWindow *window)
 {
 	gtk_widget_show (NAUTILUS_WINDOW (window)->details->statusbar);
 
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR) &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR, TRUE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_STATUS_BAR, TRUE);
 }
 
 gboolean
@@ -942,29 +930,23 @@ nautilus_navigation_window_status_bar_showing (NautilusNavigationWindow *window)
 }
 
 
-void 
+void
 nautilus_navigation_window_hide_toolbar (NautilusNavigationWindow *window)
 {
 	gtk_widget_hide (window->details->toolbar);
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR) &&
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR, FALSE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_TOOLBAR, FALSE);
 }
 
-void 
+void
 nautilus_navigation_window_show_toolbar (NautilusNavigationWindow *window)
 {
 	gtk_widget_show (window->details->toolbar);
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR) &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR, TRUE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_TOOLBAR, TRUE);
 }
 
-void 
+void
 nautilus_navigation_window_hide_sidebar (NautilusNavigationWindow *window)
 {
 	if (window->sidebar == NULL) {
@@ -974,13 +956,10 @@ nautilus_navigation_window_hide_sidebar (NautilusNavigationWindow *window)
 	nautilus_navigation_window_tear_down_sidebar (window);
 	nautilus_navigation_window_update_show_hide_menu_items (window);
 
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR) &&
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR, FALSE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR, FALSE);
 }
 
-void 
+void
 nautilus_navigation_window_show_sidebar (NautilusNavigationWindow *window)
 {
 	if (window->sidebar != NULL) {
@@ -989,10 +968,7 @@ nautilus_navigation_window_show_sidebar (NautilusNavigationWindow *window)
 
 	nautilus_navigation_window_set_up_sidebar (window);
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR) &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR, TRUE);
-	}
+	g_settings_set_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR, TRUE);
 }
 
 gboolean
@@ -1001,7 +977,7 @@ nautilus_navigation_window_sidebar_showing (NautilusNavigationWindow *window)
 	g_return_val_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (window), FALSE);
 
 	return (window->sidebar != NULL)
-		&& nautilus_horizontal_splitter_is_hidden (NAUTILUS_HORIZONTAL_SPLITTER (window->details->content_paned));
+		&& gtk_widget_get_visible (gtk_paned_get_child1 (GTK_PANED (window->details->content_paned)));
 }
 
 /**
@@ -1043,7 +1019,7 @@ nautilus_navigation_window_get_base_page_index (NautilusNavigationWindow *window
  */
 static void
 nautilus_navigation_window_show (GtkWidget *widget)
-{	
+{
 	NautilusNavigationWindow *window;
 	gboolean show_location_bar;
 	gboolean always_use_location_entry;
@@ -1052,17 +1028,17 @@ nautilus_navigation_window_show (GtkWidget *widget)
 	window = NAUTILUS_NAVIGATION_WINDOW (widget);
 
 	/* Initially show or hide views based on preferences; once the window is displayed
-	 * these can be controlled on a per-window basis from View menu items. 
+	 * these can be controlled on a per-window basis from View menu items.
 	 */
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR)) {
+	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_TOOLBAR)) {
 		nautilus_navigation_window_show_toolbar (window);
 	} else {
 		nautilus_navigation_window_hide_toolbar (window);
 	}
 
-	show_location_bar = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR);
-	always_use_location_entry = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY);
+	show_location_bar = g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_LOCATION_BAR);
+	always_use_location_entry = g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY);
 	for (walk = NAUTILUS_WINDOW(window)->details->panes; walk; walk = walk->next) {
 		NautilusNavigationWindowPane *pane = walk->data;
 		if (show_location_bar) {
@@ -1077,14 +1053,14 @@ nautilus_navigation_window_show (GtkWidget *widget)
 			nautilus_navigation_window_pane_set_bar_mode (pane, NAUTILUS_BAR_PATH);
 		}
 	}
-	
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR)) {
+
+	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
 		nautilus_navigation_window_show_sidebar (window);
 	} else {
 		nautilus_navigation_window_hide_sidebar (window);
 	}
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR)) {
+	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_STATUS_BAR)) {
 		nautilus_navigation_window_show_status_bar (window);
 	} else {
 		nautilus_navigation_window_hide_status_bar (window);
@@ -1105,20 +1081,17 @@ nautilus_navigation_window_save_geometry (NautilusNavigationWindow *window)
 		geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
 		is_maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (window)))
 				& GDK_WINDOW_STATE_MAXIMIZED;
-		
-		if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY) &&
-		    !is_maximized) {
-			eel_preferences_set
-				(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY, 
+
+		if (!is_maximized) {
+			g_settings_set_string
+				(nautilus_window_state, NAUTILUS_WINDOW_STATE_GEOMETRY,
 				 geometry_string);
 		}
 		g_free (geometry_string);
 
-		if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_MAXIMIZED)) {
-			eel_preferences_set_boolean
-				(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_MAXIMIZED, 
-				 is_maximized);
-		}
+		g_settings_set_boolean
+			(nautilus_window_state, NAUTILUS_WINDOW_STATE_MAXIMIZED,
+			 is_maximized);
 	}
 }
 
@@ -1147,9 +1120,9 @@ real_get_default_size (NautilusWindow *window,
 	if (default_width) {
 		*default_width = NAUTILUS_NAVIGATION_WINDOW_DEFAULT_WIDTH;
 	}
-	
+
 	if (default_height) {
-		*default_height = NAUTILUS_NAVIGATION_WINDOW_DEFAULT_HEIGHT;	
+		*default_height = NAUTILUS_NAVIGATION_WINDOW_DEFAULT_HEIGHT;
 	}
 }
 
@@ -1196,7 +1169,7 @@ nautilus_navigation_window_class_init (NautilusNavigationWindowClass *class)
 	NAUTILUS_WINDOW_CLASS (class)->bookmarks_placeholder = MENU_PATH_BOOKMARKS_PLACEHOLDER;
 	
 	G_OBJECT_CLASS (class)->finalize = nautilus_navigation_window_finalize;
-	GTK_OBJECT_CLASS (class)->destroy = nautilus_navigation_window_destroy;
+	GTK_WIDGET_CLASS (class)->destroy = nautilus_navigation_window_destroy;
 	GTK_WIDGET_CLASS (class)->show = nautilus_navigation_window_show;
 	GTK_WIDGET_CLASS (class)->unrealize = nautilus_navigation_window_unrealize;
 	GTK_WIDGET_CLASS (class)->window_state_event = nautilus_navigation_window_state_event;
@@ -1215,18 +1188,20 @@ nautilus_navigation_window_class_init (NautilusNavigationWindowClass *class)
 
 	g_type_class_add_private (G_OBJECT_CLASS (class), sizeof (NautilusNavigationWindowDetails));
 
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_MOUSE_BACK_BUTTON,
+				  G_CALLBACK(mouse_back_button_changed),
+				  NULL);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_MOUSE_BACK_BUTTON, 
-				      mouse_back_button_changed, 
-				      NULL);
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_MOUSE_FORWARD_BUTTON,
+				  G_CALLBACK(mouse_forward_button_changed),
+				  NULL);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_MOUSE_FORWARD_BUTTON, 
-				      mouse_forward_button_changed, 
-				      NULL);
-
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS,
-				      use_extra_mouse_buttons_changed,
-				      NULL);
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS,
+				  G_CALLBACK(use_extra_mouse_buttons_changed),
+				  NULL);
 }
 
 static NautilusWindowSlot *
