@@ -33,6 +33,7 @@
 #include "nautilus-window-pane.h"
 #include "nautilus-spatial-window.h"
 #include "nautilus-navigation-window.h"
+#include "nautilus-bookmark-list.h"
 
 #include <libnautilus-private/nautilus-directory.h>
 
@@ -177,9 +178,6 @@ void               nautilus_menus_append_bookmark_to_menu                (Nautil
                                                                           guint              merge_id,
                                                                           GCallback          refresh_callback,
                                                                           NautilusBookmarkFailedCallback failed_callback);
-#ifdef NEW_UI_COMPLETE
-void               nautilus_window_go_up                                 (NautilusWindow    *window);
-#endif
 void               nautilus_window_update_find_menu_item                 (NautilusWindow    *window);
 void               nautilus_window_zoom_in                               (NautilusWindow    *window);
 void               nautilus_window_zoom_out                              (NautilusWindow    *window);
