@@ -33,7 +33,6 @@
 #include "nautilus-actions.h"
 #include "nautilus-application.h"
 #include "nautilus-bookmarks-window.h"
-#include "nautilus-main.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-window-bookmarks.h"
 #include "nautilus-window-slot.h"
@@ -56,7 +55,6 @@
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
-#include <libnautilus-private/nautilus-horizontal-splitter.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
@@ -186,11 +184,6 @@ nautilus_window_init (NautilusWindow *window)
 	/* Register to menu provider extension signal managing menu updates */
 	g_signal_connect_object (nautilus_signaller_get_current (), "popup_menu_changed",
 			 G_CALLBACK (nautilus_window_load_extension_menus), window, G_CONNECT_SWAPPED);
-
-	gtk_quit_add_destroy (1, GTK_WIDGET (window));
-
-	/* Keep the main event loop alive as long as the window exists */
-	nautilus_main_event_loop_register (GTK_WIDGET (window));
 }
 
 /* Unconditionally synchronize the GtkUIManager of WINDOW. */
@@ -333,8 +326,8 @@ nautilus_window_go_up (NautilusWindow *window, gboolean close_behind, gboolean n
 						 NULL, NULL);
 	
 	g_object_unref (parent);
-	
-	eel_g_object_list_free (selection);
+
+	g_list_free_full (selection, g_object_unref);
 }
 
 static void
@@ -511,39 +504,14 @@ static void
 nautilus_window_set_initial_window_geometry (NautilusWindow *window)
 {
 	GdkScreen *screen;
-	guint max_width_for_screen, max_height_for_screen, min_width, min_height;
+	guint max_width_for_screen, max_height_for_screen;
 	guint default_width, default_height;
-	
+
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
 	
-	/* Don't let GTK determine the minimum size
-	 * automatically. It will insist that the window be
-	 * really wide based on some misguided notion about
-	 * the content view area. Also, it might start the
-	 * window wider (or taller) than the screen, which
-	 * is evil. So we choose semi-arbitrary initial and
-	 * minimum widths instead of letting GTK decide.
-	 */
-	/* FIXME - the above comment suggests that the size request
-	 * of the content view area is wrong, probably because of
-	 * another stupid set_usize someplace. If someone gets the
-	 * content view area's size request right then we can
-	 * probably remove this broken set_size_request() here.
-	 * - hp@redhat.com
-	 */
-
 	max_width_for_screen = get_max_forced_width (screen);
 	max_height_for_screen = get_max_forced_height (screen);
 
-	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
-			 get_min_size, (window, &min_width, &min_height));
-
-	gtk_widget_set_size_request (GTK_WIDGET (window), 
-				     MIN (min_width, 
-					  max_width_for_screen),
-				     MIN (min_height, 
-					  max_height_for_screen));
-
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
 			 get_default_size, (window, &default_width, &default_height));
 
@@ -599,9 +567,7 @@ nautilus_window_get_property (GObject *object,
 static void
 free_stored_viewers (NautilusWindow *window)
 {
-	eel_g_list_free_deep_custom (window->details->short_list_viewers, 
-				     (GFunc) g_free, 
-				     NULL);
+	g_list_free_full (window->details->short_list_viewers, g_free);
 	window->details->short_list_viewers = NULL;
 	g_free (window->details->extra_viewer);
 	window->details->extra_viewer = NULL;
@@ -953,43 +919,45 @@ nautilus_window_slot_close (NautilusWindowSlot *slot)
 }
 
 static void
-nautilus_window_size_request (GtkWidget		*widget,
-			      GtkRequisition	*requisition)
+nautilus_window_get_preferred_width (GtkWidget *widget,
+				     gint *minimal_width,
+				     gint *natural_width)
 {
 	GdkScreen *screen;
-	guint max_width;
-	guint max_height;
+	gint max_w, min_w, min_h, default_w, default_h;
+	NautilusWindow *window = NAUTILUS_WINDOW (widget);
 
-	g_assert (NAUTILUS_IS_WINDOW (widget));
-	g_assert (requisition != NULL);
+	screen = gtk_window_get_screen (GTK_WINDOW (widget));	
 
-	GTK_WIDGET_CLASS (nautilus_window_parent_class)->size_request (widget, requisition);
+	max_w = get_max_forced_width (screen);
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 get_min_size, (window, &min_w, &min_h));
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 get_default_size, (window, &default_w, &default_h));
 
-	screen = gtk_window_get_screen (GTK_WINDOW (widget));
+	*minimal_width = MIN (min_w, max_w);
+	*natural_width = MIN (default_w, max_w);
+}
 
-	/* Limit the requisition to be within 90% of the available screen 
-	 * real state.
-	 *
-	 * This way the user will have a fighting chance of getting
-	 * control of their window back if for whatever reason one of the
-	 * window's descendants decide they want to be 4000 pixels wide.
-	 *
-	 * Note that the user can still make the window really huge by hand.
-	 *
-	 * Bugs in components or other widgets that cause such huge geometries
-	 * to be requested, should still be fixed.  This code is here only to 
-	 * prevent the extremely frustrating consequence of such bugs.
-	 */
-	max_width = get_max_forced_width (screen);
-	max_height = get_max_forced_height (screen);
+static void
+nautilus_window_get_preferred_height (GtkWidget *widget,
+				      gint *minimal_height,
+				      gint *natural_height)
+{
+	GdkScreen *screen;
+	gint max_h, min_w, min_h, default_w, default_h;
+	NautilusWindow *window = NAUTILUS_WINDOW (widget);
 
-	if (requisition->width > (int) max_width) {
-		requisition->width = max_width;
-	}
-	
-	if (requisition->height > (int) max_height) {
-		requisition->height = max_height;
-	}
+	screen = gtk_window_get_screen (GTK_WINDOW (widget));	
+
+	max_h = get_max_forced_height (screen);
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 get_min_size, (window, &min_w, &min_h));
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 get_default_size, (window, &default_w, &default_h));
+
+	*minimal_height = MIN (min_h, max_h);
+	*natural_height = MIN (default_h, max_h);
 }
 
 static void
@@ -1631,7 +1599,7 @@ nautilus_send_history_list_changed (void)
 static void
 free_history_list (void)
 {
-	eel_g_object_list_free (history_list);
+	g_list_free_full (history_list, g_object_unref);
 	history_list = NULL;
 }
 
@@ -1757,12 +1725,15 @@ nautilus_forget_history (void)
 	NautilusWindowSlot *slot;
 	NautilusNavigationWindowSlot *navigation_slot;
 	GList *window_node, *l, *walk;
+	NautilusApplication *app;
+
+	app = nautilus_application_dup_singleton ();
 
 	/* Clear out each window's back & forward lists. Also, remove 
 	 * each window's current location bookmark from history list 
 	 * so it doesn't get clobbered.
 	 */
-	for (window_node = nautilus_application_get_window_list ();
+	for (window_node = gtk_application_get_windows (GTK_APPLICATION (app));
 	     window_node != NULL;
 	     window_node = window_node->next) {
 
@@ -1799,7 +1770,7 @@ nautilus_forget_history (void)
 	free_history_list ();
 
 	/* Re-add each window's current location to history list. */
-	for (window_node = nautilus_application_get_window_list ();
+	for (window_node = gtk_application_get_windows (GTK_APPLICATION (app));
 	     window_node != NULL;
 	     window_node = window_node->next) {
 		NautilusWindow *window;
@@ -1815,6 +1786,8 @@ nautilus_forget_history (void)
 			}
 		}
 	}
+
+	g_object_unref (app);
 }
 
 GList *
@@ -1999,7 +1972,8 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	G_OBJECT_CLASS (class)->set_property = nautilus_window_set_property;
 	GTK_WIDGET_CLASS (class)->destroy = nautilus_window_destroy;
 	GTK_WIDGET_CLASS (class)->show = nautilus_window_show;
-	GTK_WIDGET_CLASS (class)->size_request = nautilus_window_size_request;
+	GTK_WIDGET_CLASS (class)->get_preferred_width = nautilus_window_get_preferred_width;
+	GTK_WIDGET_CLASS (class)->get_preferred_height = nautilus_window_get_preferred_height;
 	GTK_WIDGET_CLASS (class)->realize = nautilus_window_realize;
 	GTK_WIDGET_CLASS (class)->key_press_event = nautilus_window_key_press_event;
 	class->get_title = real_get_title;
